@@ -1,28 +1,35 @@
 #
 # This file is part of Config-Model-LcdProc
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2015 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::LcdProc;
-{
-  $Config::Model::LcdProc::VERSION = '2.040';
-}
+$Config::Model::LcdProc::VERSION = '2.043';
+use 5.10.1;
+
+use Config::Model 2.043;
 
 1;
 
+# ABSTRACT: Edit and validate LcdProc configuration file
+
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::LcdProc - Edit and validate LcdProc configuration file
 
 =head1 VERSION
 
-version 2.040
+version 2.043
 
 =head1 SYNOPSIS
 
@@ -54,10 +61,6 @@ configuration file of LcdProc, i.e. C</etc/LCDd.conf>.
 This module can also be used to modify safely the content of this file
 from a Perl programs.
 
-=head1 AUTHOR
-
-Dominique Dumont, (dod at debian dot org)
-
 =head1 SEE ALSO
 
 =over
@@ -79,3 +82,17 @@ L<Config::Model>
 http://github.com/dod38fr/config-model/wiki/Using-config-model
 
 =back
+
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
+=cut
